/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2016 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy16nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy16nid ;

DATA library.&dataset ;
INFILE datafile LRECL=482;
INPUT
   USSCIDN  1-7             STMIN851  8-11           STMAX851  12-16       
   FILED  17                WITHDRWN  18             RELIEF  19            
   CTRELIEF  20             CRMHT851  21             INDTDATE DATE11.      
   FILEDATE DATE11.         PROFFN1  44-46           PROFFN2  47-49        
   PROFFN3  50-52           PROFFN4  53-55           PROFFN5  56-58        
   PROFFN6  59-61           PROFFN7  62-64           PROFFN8  65-67        
   PROFFN9  68-70           PROFFN10  71-73          PROFFN11  74-76       
   PROFFN12  77-79          PROFFN13  80-82          PROFFN14  83-85       
   PROFFN15  86-88          PROFFN16  89-91          PROFFN17  92-94       
   PROFFN18  95-97          PROFFN19  98-100         PROFFN20  101-103     
   PROFFN21  104-106        PROFFN22  107-109        PROFFN23  110-112     
   PRSENT1  113-116         PRSENT2  117-120         PRSENT3  121-124      
   PRSENT4  125-128         PRSENT5  129-132         PRSENT6  133-136      
   PRSENT7  137-140         PRSENT8  141-144         PRSENT9  145-148      
   PRSENT10  149-152        PRSENT11  153-156        PRSENT12  157-160     
   PRSENT13  161-162        PRSENT14  163-164        PRSENT15  165-166     
   PRSENT16  167-168        PRSENT17  169-170        PRSENT18  171-172     
   PRSENT19  173            PRSENT20  174-176        PRSENT21  177         
   PRSENT22  178-179        PRSENT23  180-181        PRSNDT1 DATE11.       
   PRSNDT2 DATE11.          PRSNDT3 DATE11.          PRSNDT4 DATE11.       
   PRSNDT5 DATE11.          PRSNDT6 DATE11.          PRSNDT7 DATE11.       
   PRSNDT8 DATE11.          PRSNDT9 DATE11.          PRSNDT10 DATE11.      
   PRSNDT11 DATE11.         PRSNDT12 DATE11.         PRSNDT13 DATE11.      
   PRSNDT14 DATE11.         PRSNDT15 DATE11.         PRSNDT16 DATE11.      
   PRSNDT17 DATE11.         PRSNDT18 DATE11.         PRSNDT19 DATE11.      
   PRSNDT20 DATE11.         PRSNDT21 DATE11.         PRSNDT22 DATE11.      
   PRSNDT23 DATE11.         OFFENNUM  435-436        PRCHPT1  437          
   PRCHPT2  438             PRCHPT3  439             PRCHPT4  440          
   PRCHPT5  441             PRCHPT6  442             PRCHPT7  443          
   PRCHPT8  444             PRCHPT9  445             PRCHPT10  446         
   PRCHPT11  447            PRCHPT12  448            PRCHPT13  449         
   PRCHPT14  450            PRCHPT15  451            PRCHPT16  452         
   PRCHPT17  453            PRCHPT18  454            PRCHPT19  455         
   PRCHPT20  456            PRCHPT21  457            PRCHPT22  458         
   PRCHPT23  459            PRFELN1  460             PRFELN2  461          
   PRFELN3  462             PRFELN4  463             PRFELN5  464          
   PRFELN6  465             PRFELN7  466             PRFELN8  467          
   PRFELN9  468             PRFELN10  469            PRFELN11  470         
   PRFELN12  471            PRFELN13  472            PRFELN14  473         
   PRFELN15  474            PRFELN16  475            PRFELN17  476         
   PRFELN18  477            PRFELN19  478            PRFELN20  479         
   PRFELN21  480            PRFELN22  481            PRFELN23  482         
 ;                       

FORMAT
   INDTDATE DATE9.          FILEDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.          PRSNDT15 DATE9.          PRSNDT16 DATE9.       
   PRSNDT17 DATE9.          PRSNDT18 DATE9.          PRSNDT19 DATE9.       
   PRSNDT20 DATE9.          PRSNDT21 DATE9.          PRSNDT22 DATE9.       
   PRSNDT23 DATE9.        ;
                      

LENGTH
   USSCIDN 6                STMIN851 4               STMAX851 4            
   FILED 3                  WITHDRWN 3               RELIEF 3              
   CTRELIEF 3               CRMHT851 3               PROFFN1 4             
   PROFFN2 4                PROFFN3 4                PROFFN4 4             
   PROFFN5 4                PROFFN6 4                PROFFN7 4             
   PROFFN8 4                PROFFN9 4                PROFFN10 4            
   PROFFN11 4               PROFFN12 4               PROFFN13 4            
   PROFFN14 4               PROFFN15 4               PROFFN16 4            
   PROFFN17 4               PROFFN18 4               PROFFN19 4            
   PROFFN20 4               PROFFN21 4               PROFFN22 4            
   PROFFN23 4               PRSENT1 4                PRSENT2 4             
   PRSENT3 4                PRSENT4 4                PRSENT5 4             
   PRSENT6 4                PRSENT7 4                PRSENT8 4             
   PRSENT9 4                PRSENT10 4               PRSENT11 4            
   PRSENT12 4               PRSENT13 3               PRSENT14 3            
   PRSENT15 3               PRSENT16 3               PRSENT17 3            
   PRSENT18 3               PRSENT19 3               PRSENT20 4            
   PRSENT21 3               PRSENT22 3               PRSENT23 3            
   OFFENNUM 3               PRCHPT1 3                PRCHPT2 3             
   PRCHPT3 3                PRCHPT4 3                PRCHPT5 3             
   PRCHPT6 3                PRCHPT7 3                PRCHPT8 3             
   PRCHPT9 3                PRCHPT10 3               PRCHPT11 3            
   PRCHPT12 3               PRCHPT13 3               PRCHPT14 3            
   PRCHPT15 3               PRCHPT16 3               PRCHPT17 3            
   PRCHPT18 3               PRCHPT19 3               PRCHPT20 3            
   PRCHPT21 3               PRCHPT22 3               PRCHPT23 3            
   PRFELN1 3                PRFELN2 3                PRFELN3 3             
   PRFELN4 3                PRFELN5 3                PRFELN6 3             
   PRFELN7 3                PRFELN8 3                PRFELN9 3             
   PRFELN10 3               PRFELN11 3               PRFELN12 3            
   PRFELN13 3               PRFELN14 3               PRFELN15 3            
   PRFELN16 3               PRFELN17 3               PRFELN18 3            
   PRFELN19 3               PRFELN20 3               PRFELN21 3            
   PRFELN22 3               PRFELN23 3 ;

        

RUN ;
